@@ -533,6 +533,7 @@ func (m *Md) makeTableTemplateData(t *schema.Table) map[string]interface{} {
 	number := m.config.Format.Number
 	adjust := m.config.Format.Adjust
 	hideColumns := m.config.Format.HideColumnsWithoutValues
+	showOnlyFirstParagraph := m.config.Format.ShowOnlyFirstParagraph
 
 	// Columns
 	columnsData := [][]string{}
@@ -588,6 +589,28 @@ func (m *Md) makeTableTemplateData(t *schema.Table) map[string]interface{} {
 		columnsData = append(columnsData, data)
 	}
 
+	// Viewpoints
+	viewpointsData := [][]string{
+		[]string{
+			m.config.MergedDict.Lookup("Name"),
+			m.config.MergedDict.Lookup("Definition"),
+		},
+		[]string{"----", "----------"},
+	}
+
+	for _, v := range t.Viewpoints {
+		desc := v.Desc
+		if showOnlyFirstParagraph {
+			desc = output.ShowOnlyFirstParagraph(desc)
+		}
+		data := []string{
+			fmt.Sprintf("[%s](viewpoint-%d.md)", v.Name, v.Index),
+			desc,
+		}
+
+		viewpointsData = append(viewpointsData, data)
+	}
+
 	// Constraints
 	constraintsData := [][]string{
 		[]string{
@@ -678,36 +701,40 @@ func (m *Md) makeTableTemplateData(t *schema.Table) map[string]interface{} {
 	}
 
 	// Referenced Tables
-	referencedTables := []string{}
+	hasReferencedTableWithLabels := false
 	for _, rt := range t.ReferencedTables {
-		if rt.External {
-			referencedTables = append(referencedTables, rt.Name)
-			continue
+		if len(rt.Labels) > 0 {
+			hasReferencedTableWithLabels = true
+			break
 		}
-		referencedTables = append(referencedTables, fmt.Sprintf("[%s](%s%s.md)", rt.Name, m.config.BaseUrl, mdurl.Encode(rt.Name)))
 	}
 
+	referencedTables := m.tablesData(t.ReferencedTables, number, adjust, showOnlyFirstParagraph, hasReferencedTableWithLabels)
+
 	if number {
 		columnsData = m.addNumberToTable(columnsData)
 		constraintsData = m.addNumberToTable(constraintsData)
 		indexesData = m.addNumberToTable(indexesData)
 		triggersData = m.addNumberToTable(triggersData)
+		referencedTables = m.addNumberToTable(referencedTables)
 	}
 
 	if adjust {
 		return map[string]interface{}{
 			"Table":            t,
 			"Columns":          adjustTable(columnsData),
+			"Viewpoints":       adjustTable(viewpointsData),
 			"Constraints":      adjustTable(constraintsData),
 			"Indexes":          adjustTable(indexesData),
 			"Triggers":         adjustTable(triggersData),
-			"ReferencedTables": referencedTables,
+			"ReferencedTables": adjustTable(referencedTables),
 		}
 	}
 
 	return map[string]interface{}{
 		"Table":            t,
 		"Columns":          columnsData,
+		"Viewpoints":       viewpointsData,
 		"Constraints":      constraintsData,
 		"Indexes":          indexesData,
 		"Triggers":         triggersData,
