@@ -210,6 +210,16 @@ func TestSchema_Sort(t *testing.T) {
 				},
 			},
 		},
+		Functions: []*Function{
+			&Function{
+				Name:      "b",
+				Arguments: "arg b",
+			},
+			&Function{
+				Name:      "b",
+				Arguments: "arg a",
+			},
+		},
 	}
 	if err := schema.Sort(); err != nil {
 		t.Error(err)
@@ -224,6 +234,11 @@ func TestSchema_Sort(t *testing.T) {
 	if got2 != want2 {
 		t.Errorf("got %v\nwant %v", got2, want2)
 	}
+	want3 := "arg a"
+	got3 := schema.Functions[0].Arguments
+	if got3 != want3 {
+		t.Errorf("got %v\nwant %v", got3, want3)
+	}
 }
 
 func TestRepair(t *testing.T) {
